# frozen_string_literal: true

require 'happymapper'
require_relative './node'
require_relative './issuer'
require_relative './product_details'
require_relative './product_classifications'
require_relative './rixml_type/yes_no_boolean'

module RixmlDocument
  class IssuerDetails < Node
    include HappyMapper
    tag 'IssuerDetails'
    has_many :issuers, Issuer, tag: 'Issuer', xpath: './'
  end

  class Context < Node
    include HappyMapper
    tag 'Context'

    has_one :issuer_details, IssuerDetails, xpath: './'
    has_one :product_details, ProductDetails, xpath: './'
    has_one :product_classifications, ProductClassifications, xpath: './'

    attribute :external, RixmlType::YesNoBoolean

    def issuers
      issuer_details&.issuers || []
    end
  end
end
