# frozen_string_literal: true

require 'happymapper'
require_relative './node'
require_relative './security'
require_relative './rixml_type/normalized_string'
require_relative './rixml_type/upcase_string'
require_relative './rixml_type/yes_no_boolean'

module RixmlDocument
  class SecurityDetails < Node
    include HappyMapper
    has_many :securities, Security, tag: 'Security', xpath: './'
  end

  class Issuer < Node
    include HappyMapper
    tag 'Issuer'

    has_one :security_details, SecurityDetails, tag: 'SecurityDetails', xpath: './'

    attribute :primary_indicator, RixmlType::YesNoBoolean, tag: 'primaryIndicator'
    attribute :issuer_type, RixmlType::NormalizedString, tag: 'issuerType'
    attribute :domicile_country_code, RixmlType::UpcaseString, tag: 'domicileCountryCode'

    def securities
      security_details&.securities || []
    end
  end
end
