# frozen_string_literal: true

require 'happymapper'
require_relative './node'
require_relative './product_category'
require_relative './entitlement'
require_relative './rixml_type/yes_no_boolean'

module RixmlDocument
  class EntitlementGroup < Node
    include HappyMapper
    tag 'EntitlementGroup'
    has_many :entitlements, Entitlement, tag: 'Entitlement', xpath: './'
  end

  class ProductDetails < Node
    include HappyMapper
    tag 'ProductDetails'

    has_one :product_category, ProductCategory, xpath: './'
    has_many :entitlement_groups, EntitlementGroup, xpath: './'

    attribute :publication_date_time, Time, tag: 'publicationDateTime'
    attribute :periodical_indicator, RixmlType::YesNoBoolean, tag: 'periodicalIndicator'

    def entitlements
      entitlement_groups&.map(&:entitlements)&.flatten || []
    end
  end
end
